@@ -107,6 +107,20 @@ ldm_theme_file(char *file)
     return filename;
 }
 
+void
+get_default_display_size(gint * width, gint * height)
+{
+    GdkDisplay *display = NULL;
+    GdkScreen *screen = NULL;
+    GdkRectangle my_rect;
+
+    display = gdk_display_get_default();
+    screen = gdk_display_get_default_screen(display);
+    gdk_screen_get_monitor_geometry(screen, 0, &my_rect);
+    *width = my_rect.width;
+    *height = my_rect.height;
+}
+
 GdkPixmap *root_bg = 0;
 void
 load_root_background(const gchar * filename, gboolean scale,
@@ -129,10 +143,9 @@ load_root_background(const gchar * filename, gboolean scale,
 
     GdkWindow *root = gdk_get_default_root_window();
     gint width, height;
-    gdk_drawable_get_size(GDK_DRAWABLE(root), &width, &height);
+    get_default_display_size(&width, &height);
 
     // create pixmap
-    gdk_drawable_get_size(GDK_DRAWABLE(root), &width, &height);
     root_bg = gdk_pixmap_new(GDK_DRAWABLE(root), width, height, -1);
     g_object_ref(G_OBJECT(root_bg));
 
@@ -150,19 +163,6 @@ load_root_background(const gchar * filename, gboolean scale,
     g_object_unref(G_OBJECT(image));
 }
 
-void
-set_root_background()
-{
-    GdkWindow *root = gdk_get_default_root_window();
-
-
-    // bg needs to be set and painted, so it refreshes now and in the future
-    gdk_window_set_back_pixmap(GDK_WINDOW(root), GDK_PIXMAP(root_bg), 0);
-    gdk_draw_drawable(GDK_DRAWABLE(root),
-                      gdk_gc_new(GDK_DRAWABLE(root)),
-                      GDK_DRAWABLE(root_bg), 0, 0, 0, 0, -1, -1);
-}
-
 void
 draw_background(GtkWidget * widget, gpointer data)
 {
@@ -626,7 +626,7 @@ key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer window)
 int
 main(int argc, char *argv[])
 {
-    gint lw;
+    gint lw, lh;
 
     GtkWidget *loginWindow, *prefBar;
     GdkCursor *normcursor, *busycursor;
@@ -682,9 +682,8 @@ main(int argc, char *argv[])
 
     /* Set the background */
     load_root_background(ldm_theme_file("bg"), TRUE, FALSE);
-    set_root_background();
 
-    gdk_drawable_get_size(root, &width, &height);
+    get_default_display_size(&width, &height);
 
     /* Setup the time and system labels */
     {
@@ -725,11 +724,9 @@ main(int argc, char *argv[])
     }
 
     /**** Create the login window ****/
-    gtk_window_set_position(GTK_WINDOW(loginWindow),
-                            GTK_WIN_POS_CENTER_ALWAYS);
     {
         GtkWidget *guestbox, *guestspacer1, *guestspacer2, *vbox, *vbox2,
-            *hbox;
+            *vbox2spacer, *hbox;
         GtkCellRenderer *renderer;
 
         g_signal_connect(G_OBJECT(loginWindow), "destroy",
@@ -738,8 +735,8 @@ main(int argc, char *argv[])
         gtk_widget_set_app_paintable(loginWindow, TRUE);
         g_signal_connect(loginWindow, "configure-event",
                          G_CALLBACK(draw_background), NULL);
-        //gtk_widget_set_size_request(loginWindow, width/2, height/2);
-        //gtk_widget_realize(loginWindow);
+        gtk_widget_set_size_request(loginWindow, width, height);
+        gtk_widget_realize(loginWindow);
         gtk_window_set_decorated(GTK_WINDOW(loginWindow), FALSE);
 
         logo = gtk_image_new_from_file(ldm_theme_file("logo"));
@@ -754,10 +751,12 @@ main(int argc, char *argv[])
 
         pix = gtk_image_get_pixbuf((GtkImage *) logo);
         lw = gdk_pixbuf_get_width(pix);
+        lh = gdk_pixbuf_get_height(pix);
 
 
         vbox = gtk_vbox_new(FALSE, 5);
-        vbox2 = gtk_vbox_new(FALSE, 0);
+        vbox2 = gtk_vbox_new(FALSE, ((height / 2) - lh));
+        vbox2spacer = gtk_vbox_new(FALSE, 5);
         EntryBox = gtk_hbox_new(FALSE, 5);
         hbox = gtk_hbox_new(FALSE, 0);
 
@@ -771,7 +770,7 @@ main(int argc, char *argv[])
 
         StatusMessages = gtk_label_new("");
         entry = gtk_entry_new();
-        gtk_entry_set_width_chars(GTK_ENTRY(entry), 12);
+        gtk_entry_set_width_chars(GTK_ENTRY(entry), 20);
         g_signal_connect(G_OBJECT(entry), "activate",
                          G_CALLBACK(handle_entry), root);
         // Remap tab on entry to behave as enter
@@ -842,6 +841,7 @@ main(int argc, char *argv[])
         gtk_box_pack_start(GTK_BOX(vbox), timeoutbox, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(vbox), StatusMessages, TRUE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(vbox2), vbox2spacer, FALSE, FALSE, 0);
         gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
 
         gtk_container_add(GTK_CONTAINER(loginWindow), vbox2);
@@ -915,12 +915,19 @@ main(int argc, char *argv[])
 
     gtk_widget_show_all(loginWindow);
     gtk_widget_show_all(prefBar);
+    gtk_window_move(GTK_WINDOW(loginWindow), 0, 0);
     gtk_window_move(GTK_WINDOW(prefBar), 0, height - BOTTOM_BAR_HEIGHT);
 #ifdef K12LINUX
     gtk_widget_show_all(topBar);
     gtk_window_move(GTK_WINDOW(topBar), 0, 0);
 #endif
 
+    // Center the mouse pointer on the default display
+    GdkDisplay *display = gdk_display_get_default();
+    GdkScreen *screen = gdk_display_get_default_screen(display);
+    GdkRectangle bbox;
+    gdk_screen_get_monitor_geometry(screen, 0, &bbox);
+    gdk_display_warp_pointer(display, screen, bbox.width/2, bbox.height/2);
     gdk_window_set_cursor(root, normcursor);
 
 #ifdef K12LINUX
